ColorSpace enum

Inheritance
Available extensions

Values

unknown → const ColorSpace
const ColorSpace(MDK_ColorSpace.MDK_ColorSpace_Unknown)
bt709 → const ColorSpace
const ColorSpace(MDK_ColorSpace.MDK_ColorSpace_BT709)
bt2100PQ → const ColorSpace
const ColorSpace(MDK_ColorSpace.MDK_ColorSpace_BT2100_PQ)
scrgb → const ColorSpace
const ColorSpace(MDK_ColorSpace.MDK_ColorSpace_scRGB)
bt2100hlg → const ColorSpace
const ColorSpace(MDK_ColorSpace.MDK_ColorSpace_BT2100_HLG)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<ColorSpace>
A constant List of the values in this enum, in order of their declaration.