MediaInfo class

Constructors

MediaInfo()
MediaInfo.from(Pointer<mdkMediaInfo> pci)

Properties

audio ↔ List<AudioStreamInfo>?
getter/setter pair
bitRate ↔ int
when stream is loaded, the value from container. when playing, it's updated to the realtime value
getter/setter pair
chapters ↔ List<ChapterInfo>?
getter/setter pair
duration ↔ int
duration in milliseconds. may be 0, for example live stream. duration may change when playing a stream being recorded
getter/setter pair
format ↔ String?
format or container name, for example mp4, flv
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, String>
getter/setter pair
programs ↔ List<ProgramInfo>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ int
start time in milliseconds
getter/setter pair
streams ↔ int
getter/setter pair
subtitle ↔ List<SubtitleStreamInfo>?
getter/setter pair
video ↔ List<VideoStreamInfo>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited