PlaybackState enum

Playback state

Inheritance
Available extensions

Values

notRunning → const PlaybackState
const PlaybackState(MDK_State.MDK_State_NotRunning)
stopped → const PlaybackState
const PlaybackState(MDK_State.MDK_State_Stopped)
running → const PlaybackState
const PlaybackState(MDK_State.MDK_State_Running)
playing → const PlaybackState
const PlaybackState(MDK_State.MDK_State_Playing)
paused → const PlaybackState
const PlaybackState(MDK_State.MDK_State_Paused)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
rawValue → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PlaybackState>
A constant List of the values in this enum, in order of their declaration.