ProgramInfo class

Constructors

ProgramInfo()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int
getter/setter pair
metadata ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stream ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited