StreamInfo class

Implementers

Constructors

StreamInfo()

Properties

duration ↔ int
stream duration in milliseconds
getter/setter pair
frames ↔ int
number of frames in the stream. can be 0 if not detected
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
metadata ↔ Map<String, String>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ int
stream start time in milliseconds
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited