SubtitleStreamInfo class

Inheritance

Constructors

SubtitleStreamInfo()

Properties

codec ↔ SubtitleCodecParameters
getter/setter pair
duration ↔ int
stream duration in milliseconds
getter/setter pairinherited
frames ↔ int
number of frames in the stream. can be 0 if not detected
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pairinherited
metadata ↔ Map<String, String>
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ int
stream start time in milliseconds
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited