VideoCodecParameters class

Inheritance

Constructors

VideoCodecParameters()

Properties

bFrames ↔ int
getter/setter pair
bitRate ↔ int
getter/setter pair
codec ↔ String
codec name
getter/setter pairinherited
colorSpace ↔ ColorSpace
getter/setter pair
doviProfile ↔ int
getter/setter pair
extra ↔ Uint8List?
getter/setter pairinherited
format ↔ int
pixel format
getter/setter pair
formatName ↔ String?
pixel format name
getter/setter pair
frameRate ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int
getter/setter pair
level ↔ int
getter/setter pair
par ↔ double
pixel aspect ratio
getter/setter pair
profile ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ int
fourcc
getter/setter pairinherited
width ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited